%Program to determine the full impedance of a linear dipole plasma antenna
%according to the method of Hallen (MoM) comared to an integrated radiation pattern.

function Zplasgui(action)

%Principal assumption is that the plasma current profile is uniform.

nelts = 124;		%Antenna broken into nelts-1 elements

ii = sqrt(-1);
mu_0 = 4*pi*1.e-7;
c = 3.0e8;
alpha = ii*c*mu_0/4/pi;

%Obtain the session parameters from mat5
load session

omega = 2*pi*frequency;

%Define a plasma density linear profile that looks like experiment
%Not relevant for metals
ln = 1.;
dens = dens0*exp(-1.*(z/ln)).*(1. + exp(2.*(z/ln-.5))).^(-2);
dens = dens.*exp(-4.*(.5-z/ln).^2);

dz = Length/(nelts - 1);
ddz = [dz/2., ones(1,nelts-2)*dz dz/2];
theta = linspace(0,pi/2,100);
dtheta = [pi/198/2 , ones(1,98)*pi/99/2, pi/198/2];

%Plasma stuff
eps0 = 8.85e-12;
me = 9.11e-31;
qe = 1.6022e-19;
%The plasma frequencyx
ompe2 = dens*qe*qe/me/eps0;

epsr = 1. - ompe2/omega/(omega + ii*nu);
sigma =  - ii*omega*eps0*( epsr - 1 );
ZZ = 1./sigma/pi/a/a;
ZZ = ZZ*Zfact;
beta = omega/c;

zjk = repmat(z,nelts,1);
zkj = zjk';

rjk = sqrt( a^2 + (zkj - zjk).^2);
rjkp = sqrt( a^2 + (zkj + zjk).^2);

gammajk = (exp(ii*beta*rjk)./rjk + exp(ii*beta*rjkp)./rjkp)*dz;
gammajk(:,1) = gammajk(:,1)/2.;
sjk = -repmat(ZZ,nelts,1).*sin(beta*(zjk - zkj))*dz;
sjk(:,1) = sjk(:,1)/2.;

%Hallen's equation (see book on Antennas, by J.D.Kraus)
%form the matrix for (I1,I2,   IN-1,C1)...

MM1 = tril(alpha*gammajk - sjk);
MM2 = triu(alpha*gammajk);
MM2 = MM2 - tril(MM2);
MM = MM1 + MM2;
MM(:,nelts) = -cos(beta*z(:));

y = -.5*sin(beta*z(:));
x = inv(MM)*y;

Current = [x(1:nelts-1)' 0];

h=findobj;
y=get(h,'Tag');
iaxes = find(strcmp(y,'Axes1'));
axes(h(iaxes));
plot(z,1000*abs(Current),'y','LineWidth',3)
title('Antenna current (mA)','Color',[1 1 1],'FontSize',14)
axis([0 Length 0 1000*max(abs(Current))])

% Compute the power radiation profile and the radiation resistance
%from the Poynting flux
Zant = 1./Current(1)/2.;
dI = Current.*ddz;

Etheta = ii*120*pi*sum((dI(:)*sin(theta)).*cos(beta*z(:)*cos(theta)));
Etheta = Etheta*omega/c/2/pi;

Rant = (pi/mu_0/c)*sum((Etheta.*conj(Etheta)).*(sin(theta).*dtheta));
Rant = 2.*Rant/(Current(1)*conj(Current(1)));

Thet = [theta (theta+pi/2)];
%Efield = [Etheta Etheta(100:-1:1)];

h=findobj;
y=get(h,'Tag');
iaxes = find(strcmp(y,'Axes2'));    
axes(h(iaxes));

%Rho = abs(Efield)/max(abs(Efield));
P_FLUX_iso = 0.5*Rant*(Current(1)*conj(Current(1)))/4/pi;

dBi2 = (Etheta.*conj(Etheta))/2/mu_0/c/P_FLUX_iso;

iz = find(dBi2 <= 1);
dBi2(iz) = ones(1,length(iz));

dBi2 = 10*log10(dBi2/2);
dBi = [dBi2 dBi2(100:-1:1)];

plot(dBi.*cos(Thet), dBi.*sin(Thet), 'y', 'LineWidth',3);
xlabel('Power pattern (dBi)','Color',[1 1 1],'FontSize',14)
axis([-max(dBi) max(dBi) 0 max(dBi)]); 
%hp=polar(Thet,Rho.^2,'y');
%get(hp,'LineWidth');
%set(hp,'LineWidth',3);

set(gcbf,'UserData',[real(Zant) imag(Zant) Rant])
    
